@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/vol/partition.c,v 1.11.4.3 2001/10/13 04:22:11 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/vol/partition.c,v 1.11.4.4 2002/04/21 05:04:52 zacheiss Exp $");
 
 #include <ctype.h>
 #ifdef AFS_NT40_ENV
@@ -303,7 +303,7 @@ int VCheckPartition(part, devname)
 	return -1;
 #endif
 
-#ifdef AFS_DUX40_ENV
+#if defined(AFS_DUX40_ENV) && !defined(AFS_NAMEI_ENV)
     if (status.st_ino != ROOTINO) {
 	Log("%s is not a mounted file system; ignored.\n", part);
 	return 0;
